pub trait Workload: Send + Sync { // Required method fn run_once(&self); }
A workload that can be executed many times under stress.
Execute one unit of work. MUST be safe to call concurrently from multiple threads.